@@ -3,13 +3,18 @@ from ._victor_common import _VictorCommon
 from rdkit_to_params import Params
 from ..monster import Monster
 from ..igor import Igor
+from rdkit import Chem
+from functools import singledispatchmethod
 
 class _VictorPlace(_VictorCommon):
+
+    @singledispatchmethod
     def place(self,
               smiles: str,
               long_name: str = 'ligand',
-              merging_mode='none_permissive',
+              merging_mode='expansion',
               atomnames: Optional[Dict[int, str]] = None,
+              custom_map: Optional[Dict[str, Dict[int, int]]] = None,
               extra_ligand_constraint: Union[str] = None):
         """
         Places a followup (smiles) into the protein based upon the hits.
@@ -20,23 +25,46 @@ class _VictorPlace(_VictorCommon):
         :param long_name: gets used for filenames so will get corrected
         :param merging_mode:
         :param atomnames: an optional dictionary that gets used by ``Params.from_smiles``
+        :param custom_map: see Monster.place and Monster.renumber_followup_custom_map
         :param extra_ligand_constraint:
         :return:
         """
         # ## Store
         # self._prepare_args_for_placement(smiles, long_name, merging_mode, atomnames, extra_ligand_constraint)
         def prepare_args_for_placement():
-            self._prepare_args_for_placement(smiles, long_name, merging_mode, atomnames, extra_ligand_constraint)
+            self._prepare_args_for_placement(smiles, long_name, merging_mode, atomnames, custom_map, extra_ligand_constraint)
         self._safely_do(execute=prepare_args_for_placement, resolve=self._resolve, reject=self._reject)
         # ## Analyse
         self._safely_do(execute=self._calculate_placement, resolve=self._resolve, reject=self._reject)
         return self
 
+    # this is basically backwards... but it was written that way
+    @place.register
+    def _(self,
+          mol: Chem.Mol,
+          long_name: str = 'ligand',
+          merging_mode='expansion',
+          atomnames: Optional[Dict[int, str]] = None,
+          custom_map: Optional[Dict[str, Dict[int, int]]] = None,
+          extra_ligand_constraint: Union[str] = None):
+        smiles = Chem.MolToSmiles(mol)
+        if custom_map:
+            # map applies to mol, but it needs to apply to Chem.MolFromSmiles(smiles)
+            custom_map = Monster.renumber_followup_custom_map(mol, Chem.MolFromSmiles(smiles), custom_map)
+        if atomnames is None:
+            atomnames = {}
+        for atom in mol.GetAtoms():  #: Chem.Atom
+            if atom.GetPDBResidueInfo() is not None and atom.GetIdx() not in atomnames:
+                atomnames[atom.GetIdx()] = atom.GetPDBResidueInfo().GetName()
+        self.place(smiles, long_name, merging_mode, atomnames, custom_map, extra_ligand_constraint)
+
+
     def _prepare_args_for_placement(self,
               smiles: str,
               long_name: str = 'ligand',
               merging_mode='none_permissive',
               atomnames: Optional[Dict[int, str]] = None,
+              custom_map: Optional[Dict[str, Dict[int, int]]] = None,
               extra_ligand_constraint: Union[str] = None):
         """
         Set instance attributes before calling placement
@@ -56,6 +84,8 @@ class _VictorPlace(_VictorCommon):
         self.constraint = self._get_constraint(self.extra_constraint)
         # making output folder.
         self.make_output_folder()
+        if custom_map:
+            self.custom_map = custom_map
         # make params
         self.journal.debug(f'{self.long_name} - Starting parameterisation')
         self.params = Params.from_smiles(self.smiles, name=self.ligand_resn, generic=False, atomnames=self.atomnames)
@@ -87,7 +117,8 @@ class _VictorPlace(_VictorCommon):
         # monster_throw_on_discard controls if disconnected.
         self.monster.place(mol=self.mol,
                            attachment=attachment,
-                           merging_mode=self.merging_mode)
+                           merging_mode=self.merging_mode,
+                           custom_map=self.custom_map)
         self.post_monster_step()  # empty overridable
         self.journal.debug(f'{self.long_name} - Tried {len(self.monster.mol_options)} combinations')
 
@@ -152,7 +183,3 @@ class _VictorPlace(_VictorCommon):
         if self.covalent_resn and len(
                 [d for d in self.covalent_definitions if d['residue'] == self.covalent_resn]) == 0:
             raise ValueError(f'{self.long_name} - Unrecognised type {self.covalent_resn}')
-
-
-
-
