@@ -17,6 +17,9 @@ from __future__ import annotations
 # block = Chem.MolToPDBBlock(mol)
 
 from textwrap import wrap
+import logging
+
+log = logging.getLogger(__name__)
 
 class MinimalPDBParser:
     """
@@ -72,7 +75,7 @@ class MinimalPDBParser:
             elif starts_with(row, 'ANISOU'):
                 continue
             elif self.step == 1:
-                print(f'What is {row}?')
+                log.info(f'What is {row}?')
             elif self.step > 1:
                 self.tails.append(row)
             else:
@@ -94,6 +97,10 @@ class MinimalPDBParser:
         # 22             Character     chainID      Chain identifier.
         return entry[21].strip()
 
+    def get_atomname(self, entry: str) -> str:
+        # 13 - 16        Atom          name         Atom name.
+        return entry[12:16].strip()
+
     def get_residue_name(self, entry: str) -> int:
         # https://www.wwpdb.org/documentation/file-format-content/format33/sect9.html
         # 18 - 20        Residue name  resName      Residue name.
